'From Squeak3.4 of 1 March 2003 [latest update: #5170] on 11 May 2003 at 9:25:51 pm'!
Smalltalk renameClassNamed: #CodeAuditingTool as: #StewardsTools!
Object subclass: #StewardsTools
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CodeAuditing-Core'!

!StewardsTools commentStamp: 'dgd 3/7/2003 11:02' prior: 0!
A set of tools for Stewards daily work.!


!StewardsTools methodsFor: 'browsing' stamp: 'dgd 3/7/2003 10:47'!
browseMethodsInPackage: packageName 
	"open a method browser for all methods modified in all  
	changeset for packageName"
	| changeSets methods |
	changeSets _ ChangeSorter
				changeSetsNamedSuchThat: [:each | each beginsWith: packageName].
""
	methods _ self methodsInAllChangeSets: changeSets.
	methods _ methods asSortedCollection.
	""
	MessageSet openMessageList: methods name: 'Package: ' , packageName , '  (' , methods size asString , ' methods in ' , changeSets size asString , ' changesets)'! !

!StewardsTools methodsFor: 'browsing' stamp: 'dgd 3/7/2003 11:02'!
methodsInAllChangeSets: aCollection 
	"answer all the modified methods in aCollection of changesets"
	" 
	StewardsTools new methodsInAllChangeSets: (ChangeSorter changeSetsNamedSuchThat: [:each | each beginsWith: 'MCP'])  
	"
	| methods |
	methods _ Set new.
	aCollection
		do: [:changeSet | ""
			methods
				addAll: (changeSet changedMessageListAugmented
						select: [:method | method isValid])].
	^ methods! !

!StewardsTools methodsFor: 'categorization' stamp: 'dgd 2/16/2003 15:02'!
categorizeAllMethods: aClass 
	"Categorize methods by looking in parent classes for a method  
	category."
	self categorizeAllMethods: aClass selectors in: aClass; categorizeAllMethods: aClass class selectors in: aClass class! !

!StewardsTools methodsFor: 'categorization' stamp: 'dgd 2/16/2003 15:35'!
categorizeAllMethods: selectorsCollection in: aClass 
	"Categorize methods by looking in parent classes for a method  
	category."
	| organization organizations |
	organization _ aClass organization.
	organizations _ aClass allSuperclasses
				collect: [:each | each organization].
	""
	selectorsCollection
		do: [:selector | 
			| originalCategory posibleCategories foundCategory | 
			originalCategory _ organization categoryOfElement: selector.
			""
			posibleCategories _ organizations
						collect: [:each | each categoryOfElement: selector].
			posibleCategories _ posibleCategories
						reject: [:each | each isNil].
			""
			foundCategory _ posibleCategories
						detect: [:each | each ~= ClassOrganizer default]
						ifNone: [].
			""
			(foundCategory notNil
					and: [foundCategory ~= originalCategory])
				ifTrue: [| str | 
					""
					str _ aClass name , '>>' , selector , ' --> from:''' , originalCategory , ''' to:''' , foundCategory , ''''.
					Transcript show: str;
						 cr.
					organization classify: selector under: foundCategory.
					Smalltalk changes reorganizeClass: aClass]].
	! !

!StewardsTools methodsFor: 'categorization' stamp: 'dgd 2/16/2003 15:02'!
categorizeAllUncategorizedMethods: aClass 
	"Categorize methods by looking in parent classes for a method  
	category."
	self
		categorizeAllMethods: (aClass organization listAtCategoryNamed: ClassOrganizer default)
		in: aClass;
		
		categorizeAllMethods: (aClass class organization listAtCategoryNamed: ClassOrganizer default)
		in: aClass class! !

!StewardsTools methodsFor: 'downloading changesets' stamp: 'dgd 3/7/2003 10:04'!
fileinIfCorresponds: urlCollection 
	"file in, if corresponds, each changeset in urlCollection"
	| oldChangeSets file ignored fileIns |
	oldChangeSets _ ChangeSorter allChangeSetNames.
	""
	ignored _ 0.
	fileIns _ 0.
	""
	Utilities
		informUserDuring: [:infoBar | ""
			(urlCollection asSortedCollection
				collect: [:each | each asUrl])
				withIndexDo: [:url :index | 
					| changeSet percent percentBar | 
					changeSet _ url path last sansPeriodSuffix.
					""
					(oldChangeSets includes: changeSet)
						ifTrue: [""
							Transcript show: '.'.
							ignored _ ignored + 1]
						ifFalse: [""
							file _ url retrieveContents content unzipped readStream.
							ChangeSorter newChangesFromStream: file named: changeSet.
							file close.
							fileIns _ fileIns + 1].
					""
					percent _ index / urlCollection size roundTo: 0.1.
					percentBar _ String new: (50 * percent) rounded withAll: $..
					infoBar value: (percent * 100) asString , '% [' , percentBar , ']']].
	""
	Transcript cr; cr.
	Transcript show: '  Skiped ' , ignored asString , ' changesets';
		 cr.
	Transcript show: '  Filed in ' , fileIns asString , ' changesets';
		 cr! !

!StewardsTools methodsFor: 'downloading changesets' stamp: 'dgd 3/7/2003 10:06'!
getChangeSetsUrlsFrom: anUrlOrString 
	"answer a collection of string with the full url for evey  
	changeset in the page"
	| informMessage result |
	informMessage _ 'Getting urls from "' , anUrlOrString asString , '"...'.
Transcript show: informMessage;
				 cr.
			""
	result _ Set new.
	Utilities
		informUser: informMessage
		during: [| url response parsedDocument | 
			
			url _ anUrlOrString asUrl.
			response _ HTTPSocket httpGet: anUrlOrString asString.
			""
			parsedDocument _ HtmlParser parse: response contents.
			parsedDocument
				allSubentitiesDo: [:each | ""
					(each isKindOf: HtmlAnchor)
						ifTrue: [| href | 
							href _ each href.
							('*.cs.gz' match: href)
								ifTrue: [result add: (url newFromRelativeText: href) asString]]]].
	^ result asSortedCollection! !

!StewardsTools methodsFor: 'downloading changesets' stamp: 'dgd 3/7/2003 11:02'!
updateFromSwikiPage: pageStringOrUrl 
	" 
	StewardsTools new updateFromSwikiPage: 'http://minnow.cc.gatech.edu/squeak/3005'.  
	"
	^ self
		fileinIfCorresponds: (self getChangeSetsUrlsFrom: pageStringOrUrl)! !

!StewardsTools methodsFor: 'morphs tools' stamp: 'dgd 2/16/2003 18:10'!
allMorphClasses
	"categories _ (Morph withAllSubclasses  
	collect: [:each | each category]) asSet.  
	categories _ categories  
	select: [:each | '*Morphic*' match: each]."
	| categories classesNames allClasses |
	categories _ SystemOrganization categoriesMatching: '*Morphic*'.
	classesNames _ categories
				inject: Set new
				into: [:collection :each | ""
					collection
						addAll: (SystemOrganization listAtCategoryNamed: each);
						 yourself].
	allClasses _ (classesNames
				collect: [:each | Smalltalk at: each]) addAll: Morph withAllSubclasses;
				 yourself.
	^ ChangeSet superclassOrder: allClasses asOrderedCollection! !

!StewardsTools methodsFor: 'morphs tools' stamp: 'dgd 2/16/2003 18:22'!
alphabetizeMessageCategoriesInMorphs
	self allMorphClasses
		do: [:each | 
			each organization sortCategories.
			each class organization sortCategories.

			Smalltalk changes reorganizeClass: each.
			Smalltalk changes reorganizeClass: each class]! !

!StewardsTools methodsFor: 'morphs tools' stamp: 'dgd 2/16/2003 17:49'!
categorizeAllMorphMethods
	self allMorphClasses
		do: [:each | self categorizeAllMethods: each]! !

!StewardsTools methodsFor: 'morphs tools' stamp: 'dgd 2/16/2003 18:15'!
removeEmptyCategoriesInMorphs
	self allMorphClasses
		do: [:each | 
			each organization removeEmptyCategories.
			each class organization removeEmptyCategories]! !

!StewardsTools methodsFor: 'package - kcp' stamp: 'dgd 3/7/2003 11:01'!
browseKCPMethods
	" 
	StewardsTools new browseKCPMethods  
	"
	self browseMethodsInPackage: 'KCP'! !

!StewardsTools methodsFor: 'package - kcp' stamp: 'dgd 3/7/2003 11:01'!
updateFromKCPSwikiPage
	" 
	StewardsTools new updateFromKCPSwikiPage.  
	"
	^ self updateFromSwikiPage: 'http://minnow.cc.gatech.edu/squeak/3083'! !

!StewardsTools methodsFor: 'package - mcp' stamp: 'dgd 3/7/2003 11:01'!
browseMCPMethods
	" 
	StewardsTools new browseMCPMethods  
	"
	self browseMethodsInPackage: 'MCP'! !

!StewardsTools methodsFor: 'package - mcp' stamp: 'dgd 3/7/2003 11:02'!
updateFromMCPSwikiPage
	" 
	StewardsTools new updateFromMCPSwikiPage.  
	"
	^ self updateFromSwikiPage: 'http://minnow.cc.gatech.edu/squeak/3005'! !

StewardsTools removeSelector: #updateFromSwiki!

!StewardsTools reorganize!
('browsing' browseMethodsInPackage: methodsInAllChangeSets:)
('categorization' categorizeAllMethods: categorizeAllMethods:in: categorizeAllUncategorizedMethods:)
('downloading changesets' fileinIfCorresponds: getChangeSetsUrlsFrom: updateFromSwikiPage:)
('morphs tools' allMorphClasses alphabetizeMessageCategoriesInMorphs categorizeAllMorphMethods removeEmptyCategoriesInMorphs)
('package - kcp' browseKCPMethods updateFromKCPSwikiPage)
('package - mcp' browseMCPMethods updateFromMCPSwikiPage)
!

